comparison Python/thread_pthread.h @ 38314:1fdf29a88f0e legacy-trunk

Replace PyObject_CallFunction calls with only object args with PyObject_CallFunctionObjArgs, which is 30% faster.
author Georg Brandl <georg@python.org>
date Thu, 25 May 2006 19:15:31 +0000
parents 4f97b6a229ce
children 0b2b076e5908 654c380cf8b9
comparison
equal deleted inserted replaced
38313:4a8c9f9b66e6 38314:1fdf29a88f0e